==> ejc-bid-impl-3.0.0-20231110.090842-391-sources.jar: com/ejianc/business/bid/controller/BidFileReviewController.java <==
package com.ejianc.business.bid.controller;

import java.io.Serializable;

import com.ejianc.business.bid.bean.BiddingFileReviewEntity;
import com.ejianc.business.bid.service.IRecordService;
import com.ejianc.business.bid.service.impl.BidFileReviewBpmServiceImpl;
import com.ejianc.business.bid.vo.BiddingFileReviewVO;
import com.ejianc.business.sealm.vo.YzdjVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.bid.bean.BidFileReviewEntity;
import com.ejianc.business.bid.service.IBidFileReviewService;
import com.ejianc.business.bid.vo.BidFileReviewVO;

/**
 * 投标文件评审
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("bidFileReview")
public class BidFileReviewController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private IRecordService recordService;
    @Autowired
    private BidFileReviewBpmServiceImpl bpmService;

    private static final String BILL_CODE = "BID_BIDDINGFILEREVIEW";

    @Autowired
    private IBidFileReviewService service;

    @Autowired
    private IEmployeeApi employeeApi;


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> saveOrUpdate(@RequestBody BidFileReviewVO saveorUpdateVO) {
        BidFileReviewEntity entity = BeanMapper.map(saveorUpdateVO, BidFileReviewEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveorUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        //通过建造师编号查询员工信息
        CommonResponse<EmployeeVO> byEmpmloyeeCode = employeeApi.getByEmpmloyeeCode(entity.getEmployeeCode());

        if (!byEmpmloyeeCode.isSuccess()){
            throw new BusinessException("通过EmpmloyeeCode获取员工信息数据失败！ 员工编码为： " +entity.getEmployeeCode() );
        }
        EmployeeVO employeeVO = byEmpmloyeeCode.getData();
        entity.setPid(employeeVO.getId());
        service.saveOrUpdate(entity, false);
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> queryDetail(Long id) {
        BidFileReviewEntity entity = service.selectById(id);
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        vo.setRecords(recordService.getRecord(vo.getEngineeringCode()));
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryByEnrollId 根据报名ID查询投标文件评审详情
     * @param enrollId
     * xuannl 20211118
     */
    @RequestMapping(value = "/queryByEnrollId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> queryByEnrollId(Long enrollId) {
        BidFileReviewEntity entity = service.selectByEnrollId(enrollId);
        if(null == entity){
            return CommonResponse.error("未查询到数据");
        }
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<BidFileReviewVO> vos) {
        service.removeByIds(vos.stream().map(BidFileReviewVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BidFileReviewVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("makeOrgName");
        fuzzyFields.add("billCode");
        fuzzyFields.add("employeeName");
        //建造师
        fuzzyFields.add("builtConstructor");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<BidFileReviewEntity> page = service.queryPage(param,false);
        IPage<BidFileReviewVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), BidFileReviewVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("makeOrgName");
        fuzzyFields.add("billCode");
        fuzzyFields.add("employeeName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        List<BidFileReviewEntity> list = service.queryList(param);
        //todo:字段翻译等等
        List<BidFileReviewVO> voList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(list)) {
            voList = BeanMapper.mapList(list, BidFileReviewVO.class);
            voList.forEach(vo -> {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
            });
        }
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("BidFileReview-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refBidFileReviewData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<BidFileReviewVO>> refBidFileReviewData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                       String condition,
                                                                       String searchObject,
                                                                       String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<BidFileReviewEntity> page = service.queryPage(param,false);
        IPage<BidFileReviewVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), BidFileReviewVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
    }

@Autowired
private BidFileReviewBpmServiceImpl tbpmService;
    /**
     * @Description queryDetail
     * @param
     */
    @RequestMapping(value = "/test", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> test() {
        tbpmService.afterApprovalProcessor(562622599805288457L,0,"");
        return CommonResponse.success("查询详情数据成功！");
    }

}

==> ejc-bid-impl-3.0.0-20240105.020743-399-sources.jar: com/ejianc/business/bid/controller/BidFileReviewController.java <==
package com.ejianc.business.bid.controller;

import java.io.Serializable;

import com.ejianc.business.bid.bean.BiddingFileReviewEntity;
import com.ejianc.business.bid.service.IRecordService;
import com.ejianc.business.bid.service.impl.BidFileReviewBpmServiceImpl;
import com.ejianc.business.bid.vo.BiddingFileReviewVO;
import com.ejianc.business.sealm.vo.YzdjVO;
import com.ejianc.foundation.orgcenter.api.IEmployeeApi;
import com.ejianc.foundation.orgcenter.vo.EmployeeVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.bid.bean.BidFileReviewEntity;
import com.ejianc.business.bid.service.IBidFileReviewService;
import com.ejianc.business.bid.vo.BidFileReviewVO;

/**
 * 投标文件评审
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("bidFileReview")
public class BidFileReviewController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    @Autowired
    private IRecordService recordService;
    @Autowired
    private BidFileReviewBpmServiceImpl bpmService;

    private static final String BILL_CODE = "BID_BIDDINGFILEREVIEW";

    @Autowired
    private IBidFileReviewService service;

    @Autowired
    private IEmployeeApi employeeApi;


    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> saveOrUpdate(@RequestBody BidFileReviewVO saveorUpdateVO) {
        BidFileReviewEntity entity = BeanMapper.map(saveorUpdateVO, BidFileReviewEntity.class);
        if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveorUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        //通过建造师编号查询员工信息
        CommonResponse<EmployeeVO> byEmpmloyeeCode = employeeApi.getByEmpmloyeeCode(entity.getEmployeeCode());

        EmployeeVO employeeVO = null;
        if (!byEmpmloyeeCode.isSuccess()){
            CommonResponse<List<EmployeeVO>> byCodeOrIdcard = employeeApi.getByCodeOrIdcard(Arrays.asList(entity.getConstructorIdCard()));
            if (!byCodeOrIdcard.isSuccess()) {
                List<EmployeeVO> data = byCodeOrIdcard.getData();
                if (data != null && data.size()  == 1){
                    employeeVO = data.get(0);
                }else {
                    throw new BusinessException("通过EmpmloyeeCode获取员工信息数据失败1！ 员工编码为： " + entity.getEmployeeCode() + "，身份证号：" + entity.getConstructorIdCard());
                }
            }else {
                throw new BusinessException("通过EmpmloyeeCode获取员工信息数据失败2！ 员工编码为： " + entity.getEmployeeCode() + "，身份证号：" + entity.getConstructorIdCard());
            }
        }else {
            employeeVO = byEmpmloyeeCode.getData();
        }
        entity.setPid(employeeVO.getId());
        service.saveOrUpdate(entity, false);
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> queryDetail(Long id) {
        BidFileReviewEntity entity = service.selectById(id);
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        vo.setRecords(recordService.getRecord(vo.getEngineeringCode()));
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description queryByEnrollId 根据报名ID查询投标文件评审详情
     * @param enrollId
     * xuannl 20211118
     */
    @RequestMapping(value = "/queryByEnrollId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<BidFileReviewVO> queryByEnrollId(Long enrollId) {
        BidFileReviewEntity entity = service.selectByEnrollId(enrollId);
        if(null == entity){
            return CommonResponse.error("未查询到数据");
        }
        BidFileReviewVO vo = BeanMapper.map(entity, BidFileReviewVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<BidFileReviewVO> vos) {
        service.removeByIds(vos.stream().map(BidFileReviewVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<BidFileReviewVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("makeOrgName");
        fuzzyFields.add("billCode");
        fuzzyFields.add("employeeName");
        //建造师
        fuzzyFields.add("builtConstructor");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        IPage<BidFileReviewEntity> page = service.queryPage(param,false);
        IPage<BidFileReviewVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), BidFileReviewVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("makeOrgName");
        fuzzyFields.add("billCode");
        fuzzyFields.add("employeeName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));

        List<BidFileReviewEntity> list = service.queryList(param);
        //todo:字段翻译等等
        List<BidFileReviewVO> voList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(list)) {
            voList = BeanMapper.mapList(list, BidFileReviewVO.class);
            voList.forEach(vo -> {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
            });
        }
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("BidFileReview-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refBidFileReviewData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<BidFileReviewVO>> refBidFileReviewData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                       String condition,
                                                                       String searchObject,
                                                                       String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<BidFileReviewEntity> page = service.queryPage(param,false);
        IPage<BidFileReviewVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), BidFileReviewVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
    }

@Autowired
private BidFileReviewBpmServiceImpl tbpmService;
    /**
     * @Description queryDetail
     * @param
     */
    @RequestMapping(value = "/test", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> test() {
        tbpmService.afterApprovalProcessor(562622599805288457L,0,"");
        return CommonResponse.success("查询详情数据成功！");
    }

}
